#
# (C) 2005 - Robert Vojta, http://blog.vojta.name/
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

#
# Intro to Regular Expressions in OpenOffice.org
#
#   Implementation of this module is not so good as it can be because of
# suboptimal regular expressions implementation. I'm talking about grouping
# and back references. You can't do this:
#
#  s/([dD]o) /\1X/g
#
#   You have to replace "do " and then "Do ", because you can't back reference
# part of the matched string. You can only back reference the whole matched
# string with & character. Pitty, but that's it.
#
#   From this point of view - it's better to use SearchDescriptor instead of
# ReplaceDescriptor and replace the characters by hand.
#

#
# Intro to PyUNO bridge
#
#  - pythonloader.py can't load more then one Python file, so it's neccessary
#    to have all classes in one file, that's the reason why we have everything
#    here
#
#

#
# TODO
#
#  - try to figure out \thin space problems
#  - refactorize & speedup, this is just testing code
#

import uno
import unohelper
import string

from com.sun.star.task import XJobExecutor

#
# Module info
#

MODULE  = "Vlnka"
VERSION = "0.4"
AUTHOR  = "Robert Vojta"
LICENSE = "GNU GPL"

#
##############################################################
#
# Listeners
#
#  - code by Danny Brewer (oomacros.org)
#
##############################################################
#

from com.sun.star.awt import XActionListener
class ActionListenerProcAdapter( unohelper.Base, XActionListener ):
	def __init__( self, oProcToCall, tParams=() ):
		self.oProcToCall = oProcToCall
		self.tParams = tParams

	def actionPerformed( self, oActionEvent ):
		if callable( self.oProcToCall ):
			apply( self.oProcToCall, (oActionEvent,) + self.tParams )

from com.sun.star.awt import XItemListener
class ItemListenerProcAdapter( unohelper.Base, XItemListener ):
	def __init__( self, oProcToCall, tParams=() ):
		self.oProcToCall = oProcToCall # a python procedure
		self.tParams = tParams # a tuple

	def itemStateChanged( self, oItemEvent ):
		if callable( self.oProcToCall ):
			apply( self.oProcToCall, (oItemEvent,) + self.tParams )

from com.sun.star.awt import XTextListener
class TextListenerProcAdapter( unohelper.Base, XTextListener ):
	def __init__( self, oProcToCall, tParams=() ):
		self.oProcToCall = oProcToCall # a python procedure
		self.tParams = tParams # a tuple

	def textChanged( self, oTextEvent ):
		if callable( self.oProcToCall ):
			apply( self.oProcToCall, (oTextEvent,) + self.tParams ) 

#
##############################################################
#
# Class DBModalDialog
#
#  - code by Danny Brewer (oomacros.org)
#
##############################################################
#

goAwtToolkit = None

def getAwtToolkit( ctx ):
	global goAwtToolkit
	if goAwtToolkit == None:
		goAwtToolkit = ctx.ServiceManager.createInstance( "com.sun.star.awt.Toolkit" )
	return goAwtToolkit

class DBModalDialog:

	def __init__( self, ctx, nPositionX=None, nPositionY=None, nWidth=None, nHeight=None, cTitle=None ):

		self.ctx = ctx
		self.oDialogModel = ctx.ServiceManager.createInstance( "com.sun.star.awt.UnoControlDialogModel" )
		if nPositionX != None:  self.oDialogModel.PositionX = nPositionX
		if nPositionY != None:  self.oDialogModel.PositionY = nPositionY
		if nWidth     != None:  self.oDialogModel.Width     = nWidth
		if nHeight    != None:  self.oDialogModel.Height    = nHeight
		if cTitle     != None:  self.oDialogModel.Title     = cTitle
		self.oDialogControl = ctx.ServiceManager.createInstance( "com.sun.star.awt.UnoControlDialog" )
		self.oDialogControl.setModel( self.oDialogModel )

	def release( self ):
		self.oDialogControl.dispose()

	def setDialogPosition( self, nX, nY ):
		self.oDialogModel.PositionX = nX
		self.oDialogModel.PositionY = nY

	def setDialogSize( self, nWidth, nHeight ):
		self.oDialogModel.Width = nWidth
		self.oDialogModel.Height = nHeight

	def setDialogTitle( self, cCaption ):
		self.oDialogModel.Title = cCaption

	def setVisible( self, bVisible ):
		self.oDialogControl.setVisible( bVisible )

	def addButton( self, cCtrlName, nPositionX, nPositionY, nWidth, nHeight,
		cLabel=None,
		actionListenerProc=None,
		nTabIndex=None ):
		
		self.addControl( "com.sun.star.awt.UnoControlButtonModel",
			cCtrlName, nPositionX, nPositionY, nWidth, nHeight,
			cLabel=cLabel,
			nTabIndex=nTabIndex )

		if actionListenerProc != None:
			self.addActionListenerProc( cCtrlName, actionListenerProc )

		
	def setButtonLabel( self, cCtrlName, cLabel ):
		oControl = self.getControl( cCtrlName )
		oControl.setLabel( cLabel )
   
	def addCheckBox( self, cCtrlName, nPositionX, nPositionY, nWidth, nHeight,
		cLabel=None,
		itemListenerProc=None, itemListenerProcParams = (),
		nTabIndex=None ):

		self.addControl( "com.sun.star.awt.UnoControlCheckBoxModel",
			cCtrlName, nPositionX, nPositionY, nWidth, nHeight,
			cLabel=cLabel,
			nTabIndex=nTabIndex )
		
		if itemListenerProc != None:
			self.addItemListenerProc( cCtrlName, itemListenerProc, itemListenerProcParams )

	def setCheckBoxLabel( self, cCtrlName, cLabel ):
		oControl = self.getControl( cCtrlName )
		oControl.setLabel( cLabel )

	def getCheckBoxState( self, cCtrlName ):
		oControl = self.getControl( cCtrlName )
		return oControl.getState();

	def setCheckBoxState( self, cCtrlName, nState ):
		oControl = self.getControl( cCtrlName )
		oControl.setState( nState )

	def enableCheckBoxTriState( self, cCtrlName, bTriStateEnable ):
		oControl = self.getControl( cCtrlName )
		oControl.enableTriState( bTriStateEnable )

   
	def addFixedText( self, cCtrlName, nPositionX, nPositionY, nWidth, nHeight,
		cLabel=None ):
		
		self.addControl( "com.sun.star.awt.UnoControlFixedTextModel",
			cCtrlName, nPositionX, nPositionY, nWidth, nHeight,
			cLabel=cLabel )

	def addControl( self, cCtrlServiceName,
		cCtrlName, nPositionX, nPositionY, nWidth, nHeight,
		cLabel=None,
		nTabIndex=None ):
		
		oControlModel = self.oDialogModel.createInstance( cCtrlServiceName )
		self.oDialogModel.insertByName( cCtrlName, oControlModel )

		# if negative coordinates are given for X or Y position,
		#  then make that coordinate be relative to the right/bottom
		#  edge of the dialog box instead of to the left/top.
		if nPositionX < 0: nPositionX = self.oDialogModel.Width  + nPositionX - nWidth
		if nPositionY < 0: nPositionY = self.oDialogModel.Height + nPositionY - nHeight
		oControlModel.PositionX = nPositionX
		oControlModel.PositionY = nPositionY
		oControlModel.Width = nWidth
		oControlModel.Height = nHeight
		oControlModel.Name = cCtrlName
	   
		if cLabel != None:
			oControlModel.Label = cLabel

		if nTabIndex != None:
			oControlModel.TabIndex = nTabIndex

	def getControl( self, cCtrlName ):
		oControl = self.oDialogControl.getControl( cCtrlName )
		return oControl

	def getControlModel( self, cCtrlName ):
		oControl = self.getControl( cCtrlName )
		oControlModel = oControl.getModel()
		return oControlModel

	def setControlModelProperty( self, cCtrlName, cPropertyName, uValue ):
		oControlModel = self.getControlModel( cCtrlName )
		oControlModel.setPropertyValue( cPropertyName, uValue )

	def getControlModelProperty( self, cCtrlName, cPropertyName ):
		oControlModel = self.getControlModel( cCtrlName )
		return oControlModel.getPropertyValue( cPropertyName )

	def setEnabled( self, cCtrlName, bEnabled=True ):
		self.setControlModelProperty( cCtrlName, "Enabled", bEnabled )

	def getEnabled( self, cCtrlName ):
		return self.getControlModelProperty( cCtrlName, "Enabled" )

	def setState( self, cCtrlName, nState ):
		self.setControlModelProperty( cCtrlName, "State", nState )

	def getState( self, cCtrlName ):
		return self.getControlModelProperty( cCtrlName, "State" )

	def setLabel( self, cCtrlName, cLabel ):
		self.setControlModelProperty( cCtrlName, "Label", cLabel )

	def getLabel( self, cCtrlName ):
		return self.getControlModelProperty( cCtrlName, "Label" )

	def setHelpText( self, cCtrlName, cHelpText ):
		self.setControlModelProperty( cCtrlName, "HelpText", cHelpText )

	def getHelpText( self, cCtrlName ):
		return self.getControlModelProperty( cCtrlName, "HelpText" )

	def setDesignMode( self, cCtrlName, bDesignMode=True ):
		oControl = self.getControl( cCtrlName )
		oControl.setDesignMode( bDesignMode )

	def isDesignMode( self, cCtrlName, bDesignMode=True ):
		oControl = self.getControl( cCtrlName )
		return oControl.isDesignMode()
 
	def isTransparent( self, cCtrlName, bDesignMode=True ):
		oControl = self.getControl( cCtrlName )
		return oControl.isTransparent()
	 
	def setPosition( self, cCtrlName, nPositionX, nPositionY ):
		self.setControlModelProperty( cCtrlName, "PositionX", nPositionX )
		self.setControlModelProperty( cCtrlName, "PositionY", nPositionY )
	def setPositionX( self, cCtrlName, nPositionX ):
		self.setControlModelProperty( cCtrlName, "PositionX", nPositionX )
	def setPositionY( self, cCtrlName, nPositionY ):
		self.setControlModelProperty( cCtrlName, "PositionY", nPositionY )
	def getPositionX( self, cCtrlName ):
		return self.getControlModelProperty( cCtrlName, "PositionX" )
	def getPositionY( self, cCtrlName ):
		return self.getControlModelProperty( cCtrlName, "PositionY" )

	def setSize( self, cCtrlName, nWidth, nHeight ):
		self.setControlModelProperty( cCtrlName, "Width", nWidth )
		self.setControlModelProperty( cCtrlName, "Height", nHeight )
	def setWidth( self, cCtrlName, nWidth ):
		self.setControlModelProperty( cCtrlName, "Width", nWidth )
	def setHeight( self, cCtrlName, nHeight ):
		self.setControlModelProperty( cCtrlName, "Height", nHeight )
	def getWidth( self, cCtrlName ):
		return self.getControlModelProperty( cCtrlName, "Width" )
	def getHeight( self, cCtrlName ):
		return self.getControlModelProperty( cCtrlName, "Height" )

	def setTabIndex( self, cCtrlName, nWidth, nTabIndex ):
		self.setControlModelProperty( cCtrlName, "TabIndex", nTabIndex )
	def getTabIndex( self, cCtrlName ):
		return self.getControlModelProperty( cCtrlName, "TabIndex" )

	def setStep( self, cCtrlName, nWidth, nStep ):
		self.setControlModelProperty( cCtrlName, "Step", nStep )
	def getStep( self, cCtrlName ):
		return self.getControlModelProperty( cCtrlName, "Step" )

	def setTag( self, cCtrlName, nWidth, cTag ):
		self.setControlModelProperty( cCtrlName, "Tag", cTag )
	def getTag( self, cCtrlName ):
		return self.getControlModelProperty( cCtrlName, "Tag" )

	def addActionListenerProc( self, cCtrlName, actionListenerProc ):
		oControl = self.getControl( cCtrlName )
		oActionListener = ActionListenerProcAdapter( actionListenerProc )
		oControl.addActionListener( oActionListener )

	def addItemListenerProc( self, cCtrlName, itemListenerProc, params ):
		oControl = self.getControl( cCtrlName )
		oActionListener = ItemListenerProcAdapter( itemListenerProc, params )
		oControl.addItemListener( oActionListener ) 

	def doModalDialog( self ):
		self.oDialogControl.setVisible( True )
		self.oDialogControl.execute()

	def endExecute( self ):
		self.oDialogControl.endExecute()

#
##############################################################
#
# Class RegularExpressions
#
#  - this class is about regular expressions, search & replace
#  - one function removes the empty paragraphs at the end of
#    the document
#
##############################################################
#

class RegularExpressions:
	def __init__( self ):

		# 0 - internal name
		# 1 - checkbox text
		# 2 - enabled by default
		# 3 - case sensitive by default
		# 4 - regular expression
		# 5 - method to call
		# 6 - help text

		self.groups = [ 

			[
				unicode( "Vložit nezalomitelnou mezeru u:|Nezalomitelná mezera vložena:", "utf-8" ), [

				[ 'prepositions', unicode( "jednohláskových předložek a spojek", "utf-8" ),
					True, False,
					unicode( "\\<(k|s|v|z|o|u|i|a) ", "utf-8" ),
					unicode( "Nahradí mezeru za jednohláskovou předložkou či spojkou " +
						"(k,s,v,z,o,u,i,a) nezalomitelnou mezerou.", "utf-8" ),
					self.replaceStrings, " ", u"\xa0" ],

				[ 'prepositions2', unicode( "dvouhláskových předložek", "utf-8" ),
					True, False,
					unicode( "\\<(do|ke|ku|na|od|po|se|ve|za|ze|že|až|oč) ", "utf-8" ),
					unicode( "Nahradí mezeru za dvouhláskovou předložkou " +
						"(do, na, ke, ve, ...) nezalomitelnou mezerou.", "utf-8" ),
					self.replaceStrings, " ", u"\xa0" ],

				[ 'units', unicode( "jednotek (kg, cm, ...)", "utf-8" ),
					False, False,
				    unicode( "[:digit:] "+
			    	"(cl|cm|dl|dm|g|hl|sk|kg|km|ks|l|m|mg|ml|mm|t|kč|Kč)", "utf-8" ),
					unicode( "Nahradí mezeru mezi číslem a jednotkou (cl, cm, kg, ...) " +
						"nezalomitelnou mezerou.", "utf-8" ),
					self.replaceStrings, " ", u"\xa0" ],

				[ 'degrees', unicode( "titulů, oslovení a hodností", "utf-8" ),
					False, False,
					unicode( "\\<(Doc|Dr|gen||Ing|JUDr|kpt|Mgr|" +
						"mjr|MUDr|MVDr|p|PaeDr|PhDr|pí" +
						"|p?por|p?plk|Prof|RNDr|sl)\. ", "utf-8"),
					unicode( "Nahradí mezeru mezi titulem (Ing., Mgr., ...), oslovením (p., pí.) či " +
						"hodností (plk., ...) nezalomitelnou mezerou.", "utf-8" ),
					self.replaceStrings, " ", u"\xa0" ],

				[ 'numbers', unicode( "skupin čísel", "utf-8" ),
					False, False,
					"([:digit:]+ ){1,}[:digit:]+\\>",
					unicode( "Nahradí mezery mezi skupinami čísel nezalomitelnou mezerou.", "utf-8" ),
					self.replaceStrings, " ", u"\xa0" ],

				[ 'dates', unicode( "číselně vyjádřených dat", "utf-8" ),
					False, False,
					"([:digit:]{1,2}\. ){2}[:digit:]{4}",
					unicode( "Nahradí mezery mezi dnem měsíc a měsícem rokem nezalomitelnou mezerou.",
						"utf-8" ),
					self.replaceStrings, " ", u"\xa0" ],

				[ 'marks', unicode( "značek °, %", "utf-8" ),
					False, False,
					unicode( "([:digit:] [°%]|[:alpha:] %)", "utf-8" ),
					unicode( "Nahradí mezeru mezi číslem a znaky °% nezalomitelnou mezerou.", "utf-8" ),
					self.replaceStrings, " ", u"\xa0" ] ]
			],

			[ unicode( "Další možnosti nastavení:|Počet provedených úkonů:", "utf-8" ), [

				[ 'paraSpaces', unicode( "smaž mezery na konci odstavce", "utf-8" ),
					True, False,
					" {1,}$",
					unicode( "Smaže mezery na koncích odstavců.", "utf-8" ),
					self.replaceStrings, " ", "" ],
				
				[ 'emptyParas', unicode( "smaž prázdné řádky na konci", "utf-8" ),
					True, False,
					"^$",
					unicode( "Smaže prázdné řádky a mezery na konci dokumentu.", "utf-8" ),
					self.removeEmptyParagraphs ] ]
			]
		]

		self.noReplacement = {}

	#
	# Generate dialog controls
	#
	#  - checkboxes for settings or fixedtexts for progress
	#
	def generateDialogControls( self, dialog, type, startX = 10, startY = 10,
		hStep = 5, vStep = 12, width = 110, height = 14 ):

		pos = 0
		for group in self.groups:
			if type == "settings":
				dialog.addFixedText( "fixedText" + str(pos), startX, startY + pos * vStep,
					width, height, string.split( group[0], "|" )[0] )
			if type == "progress":
				dialog.addFixedText( "fixedText" + str(pos), startX, startY + pos * vStep,
					width, height, string.split( group[0], "|" )[1] )

			pos += 1

			for expr in group[1]:
				if type == "settings":
					dialog.addCheckBox( expr[0] + "CheckBox", startX + hStep, startY + pos * vStep,
						width, height, expr[1],
						itemListenerProc = self.toggleByKey,
						itemListenerProcParams = ( expr[0], ) )
					dialog.setCheckBoxState( expr[0] + "CheckBox", int( expr[2] ) )
					dialog.setHelpText( expr[0] + "CheckBox", expr[5] )

				if type == "progress":
					dialog.addFixedText( expr[0] + "fT", startX + hStep, startY + pos * vStep,
						width, height, expr[1] )
					dialog.addFixedText( expr[0] + "fTP", startX + hStep + width, startY + pos * vStep,
						15, height, "---" )

				pos += 1

	#
	# enabled/disable item in group
	#
	def toggleByKey( self, oItemEvent, name ):
		for group in self.groups:
			for expr in group[1]:
				if expr[0] == name:
					expr[2] = not expr[2]

	#
	# remove empty paragraphs at the end of the document
	#
	def removeEmptyParagraphs( self, expr ):
		self.resetCounter( expr[0] )

		cursor = self.doc.Text.createTextCursor()
		cursor.gotoEnd( False )
		cursor.goLeft( 1, True )
		while cursor.String[0] in ( " ", "\n" ):
			self.updateCounter( expr[0], self.noReplacement[expr[0]] + 1)
			cursor.goLeft( 1, True )

		if self.noReplacement[expr[0]] > 0:
			cursor.goRight( 1, True )
			cursor.String = ""

	#
	# search with regexp and replace by hand
	#
	def replaceStrings( self, expr ):
		self.resetCounter( expr[0] )
		self.search.SearchString = expr[4]

		found = self.doc.findFirst( self.search )
		while found:
			found.String = string.replace( found.String, expr[7], expr[8] )
			self.updateCounter( expr[0], self.noReplacement[expr[0]] + 1 )
			found = self.doc.findNext( found.End, self.search )
	
	#
	# reset number of replacement to zero
	#
	def resetCounter( self, key ):
		self.noReplacement[key] = 0

	#
	# update number of replacement to the given number and update progress
	# dialog too
	#
	def updateCounter( self, key, number ):
		self.noReplacement[key] = number
		self.pDialog.updateProgress( key, self.noReplacement[key] )

	#
	# start the regular expressions funny stuff
	#
	def trigger( self, doc, pDialog ):
		try:
			self.pDialog = pDialog
			self.doc = doc

			self.search = self.doc.createSearchDescriptor()
			self.search.SearchRegularExpression = True

			for group in self.groups:
				for expr in group[1]:
					if expr[2]:
						apply( expr[6], (expr,) )
		except:
			pass

#
##############################################################
#
# Class AboutDialog
#
#  - simple about dialog
#
##############################################################
#

class AboutDialog( DBModalDialog ):
	def __init__( self, ctx ):
		DBModalDialog.__init__( self, ctx )

		self.setDialogPosition( 60, 50 )
		self.setDialogSize( 130, 70 )
		self.setDialogTitle( "Vlnka - O makru" )

		self.addFixedText( "fT1", 10, 10, 50, 14,
			unicode("Makro: %s" % MODULE, "utf-8" ) )

		self.addFixedText( "fT2", 10, 22, 50, 14,
			unicode("Verze: %s" % VERSION, "utf-8" ) )
		
		self.addFixedText( "fT3", 60, 10, 60, 14,
			unicode("Autor: %s" % AUTHOR, "utf-8" ) )
		self.setHelpText( "fT3",
			unicode( "Napsat mi můžete na robert@vojta.name ;-)", "utf-8" ) )

		self.addFixedText( "fT4", 60, 22, 60, 14,
			unicode("Licence: %s" % LICENSE, "utf-8" ) )
				
		self.addButton( "buttonOK", -10, -10, 40, 14, "OK",
			actionListenerProc = self.buttonOKClicked )

	def buttonOKClicked( self, oActionEvent ):
		self.endExecute()
	

class SettingsDialog( DBModalDialog ):
	def __init__( self, ctx ):
		DBModalDialog.__init__( self, ctx )

		self.setDialogPosition( 60, 50 )
		self.setDialogSize( 200, 150 )
		self.setDialogTitle( unicode( "Vlnka - Nastavení", "utf-8" ) )

		self.addButton( "buttonOK", -10, 10, 40, 14, "OK",
			            actionListenerProc = self.buttonOKClicked )

		self.addButton( "buttonCancel", -10, 30, 40, 14, "Storno",
			            actionListenerProc = self.buttonCancelClicked )

		self.addButton( "buttonAbout", -10, -10, 40, 14, "O Vlnce",
						actionListenerProc = self.buttonAboutClicked )
		
		self.replace = False

	def buttonOKClicked( self, oActionEvent ):
		self.replace = True
		self.endExecute()

	def buttonCancelClicked( self, oActionEvent ):
		self.endExecute()

	def buttonAboutClicked( self, oActionEvent ):
		aboutDialog = AboutDialog( self.ctx )
		aboutDialog.doModalDialog()

#
##############################################################
#
# Class ProgressDialog
#
#  - simple dialog with progress
#
##############################################################
#

class ProgressDialog( DBModalDialog ):
	def __init__( self, ctx ):
		DBModalDialog.__init__( self, ctx )

		self.setDialogPosition( 60, 50 )
		self.setDialogSize( 200, 150 )
		self.setDialogTitle( unicode( "Vlnka - Nahrazuji ...", "utf-8" ) )

		self.addButton( "buttonOK", -10, 10, 40, 14, "OK",
			actionListenerProc = self.buttonOKClicked )
		self.setEnabled( "buttonOK", False )

	def updateProgress( self, key, number ):
		self.setLabel( key + "fTP", "%dx" % number )
		
	def done( self ):
		self.setDialogTitle( unicode( "Vlnka - Výsledky nahrazování", "utf-8" ) )
		self.setEnabled( "buttonOK", True )

	def buttonOKClicked( self, oActionEvent):
		self.endExecute()
#
##############################################################
#
# Class Vlnka
#
#  - dialogs wrapper
#  - regular expressions wrapper
#
##############################################################
#

class Vlnka( unohelper.Base, XJobExecutor ):
	def __init__( self, ctx ):
		self.ctx = ctx

	def trigger( self, args ):
		desktop = self.ctx.ServiceManager.createInstanceWithContext(
			"com.sun.star.frame.Desktop", self.ctx )

		doc = desktop.getCurrentComponent()

		regExps = RegularExpressions()
		settingsDialog =  SettingsDialog( self.ctx )
		regExps.generateDialogControls( settingsDialog, "settings" )
		settingsDialog.doModalDialog()

		if settingsDialog.replace:
			pDialog = ProgressDialog( self.ctx )
			regExps.generateDialogControls( pDialog, "progress" )
			pDialog.setVisible( True )
			regExps.trigger( doc, pDialog )
			pDialog.done()
			pDialog.doModalDialog()

g_ImplementationHelper = unohelper.ImplementationHelper()
g_ImplementationHelper.addImplementation(
		Vlnka,
		"org.openoffice.rvojta.Vlnka",
		("com.sun.star.task.Job",),)

#
##############################################################################
#
# Following code is executed only if the Vlnka.py is called from the
# Python interpreter from the command line
#
#  - use the python interpreter from the OO.o, not from your system
#  - uncomment following code if you want to use it ;-) (""")
#
##############################################################################
#
"""
if __name__ == "__main__":
	import os

	# Start OpenOffice.org, listen for connections and open testing document
	os.system( "/etc/openoffice.org-1.9/program/soffice '-accept=socket,host=localhost,port=2002;urp;' -writer ./Vlnka.odt &" )
	
	# Get local context info
	localContext = uno.getComponentContext()
	resolver = localContext.ServiceManager.createInstanceWithContext(
		"com.sun.star.bridge.UnoUrlResolver", localContext )

	ctx = None

	# Wait until the OO.o starts and connection is established
	while ctx == None:
		try:
			ctx = resolver.resolve(
				"uno:socket,host=localhost,port=2002;urp;StarOffice.ComponentContext" )
		except: 
			pass
	
	# Trigger our job
	vlnka = Vlnka( ctx )
	vlnka.trigger( () )
"""
